==> aws-java-sdk-events-1.10.54-sources.jar: com/amazonaws/services/cloudwatchevents/model/transform/RemoveTargetsResultEntryJsonMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cloudwatchevents.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;
import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.cloudwatchevents.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * RemoveTargetsResultEntryMarshaller
 */
public class RemoveTargetsResultEntryJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a JSONWriter
     */
    public void marshall(RemoveTargetsResultEntry removeTargetsResultEntry,
            JSONWriter jsonWriter) {
        if (removeTargetsResultEntry == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonWriter.object();

            if (removeTargetsResultEntry.getTargetId() != null) {
                jsonWriter.key("TargetId").value(
                        removeTargetsResultEntry.getTargetId());
            }

            if (removeTargetsResultEntry.getErrorCode() != null) {
                jsonWriter.key("ErrorCode").value(
                        removeTargetsResultEntry.getErrorCode());
            }

            if (removeTargetsResultEntry.getErrorMessage() != null) {
                jsonWriter.key("ErrorMessage").value(
                        removeTargetsResultEntry.getErrorMessage());
            }

            jsonWriter.endObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static RemoveTargetsResultEntryJsonMarshaller instance;

    public static RemoveTargetsResultEntryJsonMarshaller getInstance() {
        if (instance == null)
            instance = new RemoveTargetsResultEntryJsonMarshaller();
        return instance;
    }

}

==> aws-java-sdk-events-1.11.29-sources.jar: com/amazonaws/services/cloudwatchevents/model/transform/RemoveTargetsResultEntryJsonMarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not
 * use this file except in compliance with the License. A copy of the License is
 * located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.cloudwatchevents.model.transform;

import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.cloudwatchevents.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * RemoveTargetsResultEntryMarshaller
 */
public class RemoveTargetsResultEntryJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(RemoveTargetsResultEntry removeTargetsResultEntry,
            StructuredJsonGenerator jsonGenerator) {

        if (removeTargetsResultEntry == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (removeTargetsResultEntry.getTargetId() != null) {
                jsonGenerator.writeFieldName("TargetId").writeValue(
                        removeTargetsResultEntry.getTargetId());
            }
            if (removeTargetsResultEntry.getErrorCode() != null) {
                jsonGenerator.writeFieldName("ErrorCode").writeValue(
                        removeTargetsResultEntry.getErrorCode());
            }
            if (removeTargetsResultEntry.getErrorMessage() != null) {
                jsonGenerator.writeFieldName("ErrorMessage").writeValue(
                        removeTargetsResultEntry.getErrorMessage());
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static RemoveTargetsResultEntryJsonMarshaller instance;

    public static RemoveTargetsResultEntryJsonMarshaller getInstance() {
        if (instance == null)
            instance = new RemoveTargetsResultEntryJsonMarshaller();
        return instance;
    }

}
